@@ -1,5 +1,8 @@
+import pandas as pd
+import numpy as np
+import os
 
-def Gene2Entrez():
+def Gene2Entrez(self):
     DAVID_Entrez = pd.read_csv('ENTREZ_GENE_ID2DAVID_GENE_NAME.txt',sep = '\t',header = None)
     DAVID_Entrez = DAVID_Entrez.rename(columns = {0: 'ENTREZ', 1: 'Map'})
     Map = DAVID_Entrez['Map'].values.tolist()
